
if (n == 1)
orient tall;print cartoon/SF_cartoon_1.ps;
elseif (n==2)
orient tall;print cartoon/SF_cartoon_2.ps;
elseif (n==3)
orient tall;print cartoon/SF_cartoon_3.ps;
elseif (n==4)
orient tall;print cartoon/SF_cartoon_4.ps;
elseif (n==5)
orient tall;print cartoon/SF_cartoon_5.ps;
elseif (n==6)
orient tall;print cartoon/SF_cartoon_6.ps;
elseif (n==7)
orient tall;print cartoon/SF_cartoon_7.ps;
elseif (n==8)
orient tall;print cartoon/SF_cartoon_8.ps;
elseif (n==9)
orient tall;print cartoon/SF_cartoon_9.ps;
elseif (n==10)
orient tall;print cartoon/SF_cartoon_10.ps;
elseif (n==11)
orient tall;print cartoon/SF_cartoon_11.ps;
elseif (n==12)
orient tall;print cartoon/SF_cartoon_12.ps;
elseif (n==13)
orient tall;print cartoon/SF_cartoon_13.ps;
elseif (n==14)
orient tall;print cartoon/SF_cartoon_14.ps;
elseif (n==15)
orient tall;print cartoon/SF_cartoon_15.ps;
elseif (n==16)
orient tall;print cartoon/SF_cartoon_16.ps;
elseif (n==17)
orient tall;print cartoon/SF_cartoon_17.ps;
elseif (n==18)
orient tall;print cartoon/SF_cartoon_18.ps;
elseif (n==19)
orient tall;print cartoon/SF_cartoon_19.ps;
elseif (n==20)
orient tall;print cartoon/SF_cartoon_20.ps;
elseif (n==21)
orient tall;print cartoon/SF_cartoon_21.ps;
elseif (n==22)
orient tall;print cartoon/SF_cartoon_22.ps;
elseif (n==23)
orient tall;print cartoon/SF_cartoon_23.ps;
elseif (n==24)
orient tall;print cartoon/SF_cartoon_24.ps;
elseif (n==25)
orient tall;print cartoon/SF_cartoon_25.ps;
elseif (n==26)
orient tall;print cartoon/SF_cartoon_26.ps;
elseif (n==27)
orient tall;print cartoon/SF_cartoon_27.ps;
elseif (n==28)
orient tall;print cartoon/SF_cartoon_28.ps;
elseif (n==29)
orient tall;print cartoon/SF_cartoon_29.ps;
elseif (n==30)
orient tall;print cartoon/SF_cartoon_30.ps;
elseif (n==31)
orient tall;print cartoon/SF_cartoon_31.ps;
elseif (n==32)
orient tall;print cartoon/SF_cartoon_32.ps;
elseif (n==33)
orient tall;print cartoon/SF_cartoon_33.ps;
elseif (n==34)
orient tall;print cartoon/SF_cartoon_34.ps;
elseif (n==35)
orient tall;print cartoon/SF_cartoon_35.ps;
elseif (n==36)
orient tall;print cartoon/SF_cartoon_36.ps;
elseif (n==37)
orient tall;print cartoon/SF_cartoon_37.ps;
elseif (n==38)
orient tall;print cartoon/SF_cartoon_38.ps;
elseif (n==39)
orient tall;print cartoon/SF_cartoon_39.ps;
elseif (n==40)
orient tall;print cartoon/SF_cartoon_40.ps;
elseif (n==41)
orient tall;print cartoon/SF_cartoon_41.ps;
elseif (n==42)
orient tall;print cartoon/SF_cartoon_42.ps;
elseif (n==43)
orient tall;print cartoon/SF_cartoon_43.ps;
elseif (n==44)
orient tall;print cartoon/SF_cartoon_44.ps;
elseif (n==45)
orient tall;print cartoon/SF_cartoon_45.ps;
elseif (n==46)
orient tall;print cartoon/SF_cartoon_46.ps;
elseif (n==47)
orient tall;print cartoon/SF_cartoon_47.ps;
elseif (n==48)
orient tall;print cartoon/SF_cartoon_48.ps;
elseif (n==49)
orient tall;print cartoon/SF_cartoon_49.ps;
elseif (n==50)
orient tall;print cartoon/SF_cartoon_50.ps;
elseif (n==51)
orient tall;print cartoon/SF_cartoon_51.ps;
elseif (n==52)
orient tall;print cartoon/SF_cartoon_52.ps;
elseif (n==53)
orient tall;print cartoon/SF_cartoon_53.ps;
elseif (n==54)
orient tall;print cartoon/SF_cartoon_54.ps;
elseif (n==55)
orient tall;print cartoon/SF_cartoon_55.ps;
elseif (n==56)
orient tall;print cartoon/SF_cartoon_56.ps;
elseif (n==57)
orient tall;print cartoon/SF_cartoon_57.ps;
elseif (n==58)
orient tall;print cartoon/SF_cartoon_58.ps;
elseif (n==59)
orient tall;print cartoon/SF_cartoon_59.ps;
elseif (n==40)
orient tall;print cartoon/SF_cartoon_60.ps;
elseif (n==61)
orient tall;print cartoon/SF_cartoon_61.ps;
elseif (n==62)
orient tall;print cartoon/SF_cartoon_62.ps;
elseif (n==63)
orient tall;print cartoon/SF_cartoon_63.ps;
elseif (n==64)
orient tall;print cartoon/SF_cartoon_64.ps;
elseif (n==65)
orient tall;print cartoon/SF_cartoon_65.ps;
elseif (n==66)
orient tall;print cartoon/SF_cartoon_66.ps;
elseif (n==67)
orient tall;print cartoon/SF_cartoon_67.ps;
elseif (n==68)
orient tall;print cartoon/SF_cartoon_68.ps;
elseif (n==69)
orient tall;print cartoon/SF_cartoon_69.ps;
elseif (n==40)
orient tall;print cartoon/SF_cartoon_40.ps;
elseif (n==41)
orient tall;print cartoon/SF_cartoon_41.ps;
elseif (n==42)
orient tall;print cartoon/SF_cartoon_42.ps;
elseif (n==43)
orient tall;print cartoon/SF_cartoon_43.ps;
elseif (n==44)
orient tall;print cartoon/SF_cartoon_44.ps;
elseif (n==45)
orient tall;print cartoon/SF_cartoon_45.ps;
elseif (n==46)
orient tall;print cartoon/SF_cartoon_46.ps;
elseif (n==47)
orient tall;print cartoon/SF_cartoon_47.ps;
elseif (n==48)
orient tall;print cartoon/SF_cartoon_48.ps;
elseif (n==49)
orient tall;print cartoon/SF_cartoon_49.ps;
elseif (n==50)
orient tall;print cartoon/SF_cartoon_50.ps;
elseif (n==51)
orient tall;print cartoon/SF_cartoon_51.ps;
elseif (n==52)
orient tall;print cartoon/SF_cartoon_52.ps;
elseif (n==53)
orient tall;print cartoon/SF_cartoon_53.ps;
elseif (n==54)
orient tall;print cartoon/SF_cartoon_54.ps;
elseif (n==55)
orient tall;print cartoon/SF_cartoon_55.ps;
elseif (n==56)
orient tall;print cartoon/SF_cartoon_56.ps;
elseif (n==57)
orient tall;print cartoon/SF_cartoon_57.ps;
elseif (n==58)
orient tall;print cartoon/SF_cartoon_58.ps;
elseif (n==59)
orient tall;print cartoon/SF_cartoon_59.ps;
elseif (n==60)
orient tall;print cartoon/SF_cartoon_60.ps;
elseif (n==61)
orient tall;print cartoon/SF_cartoon_61.ps;
elseif (n==62)
orient tall;print cartoon/SF_cartoon_62.ps;
elseif (n==63)
orient tall;print cartoon/SF_cartoon_63.ps;
elseif (n==64)
orient tall;print cartoon/SF_cartoon_64.ps;
elseif (n==65)
orient tall;print cartoon/SF_cartoon_65.ps;
elseif (n==66)
orient tall;print cartoon/SF_cartoon_66.ps;
elseif (n==67)
orient tall;print cartoon/SF_cartoon_67.ps;
elseif (n==68)
orient tall;print cartoon/SF_cartoon_68.ps;
elseif (n==69)
orient tall;print cartoon/SF_cartoon_69.ps;
elseif (n==70)
orient tall;print cartoon/SF_cartoon_70.ps;
elseif (n==71)
orient tall;print cartoon/SF_cartoon_71.ps;
elseif (n==72)
orient tall;print cartoon/SF_cartoon_72.ps;
elseif (n==73)
orient tall;print cartoon/SF_cartoon_73.ps;
elseif (n==74)
orient tall;print cartoon/SF_cartoon_74.ps;
elseif (n==75)
orient tall;print cartoon/SF_cartoon_75.ps;
elseif (n==76)
orient tall;print cartoon/SF_cartoon_76.ps;
elseif (n==77)
orient tall;print cartoon/SF_cartoon_77.ps;
elseif (n==78)
orient tall;print cartoon/SF_cartoon_78.ps;
elseif (n==79)
orient tall;print cartoon/SF_cartoon_79.ps;
elseif (n==80)
orient tall;print cartoon/SF_cartoon_80.ps;
elseif (n==81)
orient tall;print cartoon/SF_cartoon_81.ps;
elseif (n==82)
orient tall;print cartoon/SF_cartoon_82.ps;
elseif (n==83)
orient tall;print cartoon/SF_cartoon_83.ps;
elseif (n==84)
orient tall;print cartoon/SF_cartoon_84.ps;
elseif (n==85)
orient tall;print cartoon/SF_cartoon_85.ps;
elseif (n==86)
orient tall;print cartoon/SF_cartoon_86.ps;
elseif (n==87)
orient tall;print cartoon/SF_cartoon_87.ps;
elseif (n==88)
orient tall;print cartoon/SF_cartoon_88.ps;
elseif (n==89)
orient tall;print cartoon/SF_cartoon_89.ps;
elseif (n==90)
orient tall;print cartoon/SF_cartoon_90.ps;

end;

